QDeviceIO
===================
.. autoclass:: dvg_qdeviceio.QDeviceIO
   :members: ,
   :member-order: bysource
   :show-inheritance:

Signals
--------------------

.. autoattribute:: dvg_qdeviceio.QDeviceIO.signal_DAQ_updated
.. autoattribute:: dvg_qdeviceio.QDeviceIO.signal_jobs_updated
.. autoattribute:: dvg_qdeviceio.QDeviceIO.signal_DAQ_paused
.. autoattribute:: dvg_qdeviceio.QDeviceIO.signal_connection_lost

Methods
--------------------

.. automethod:: dvg_qdeviceio.QDeviceIO.attach_device
.. automethod:: dvg_qdeviceio.QDeviceIO.create_worker_DAQ
.. automethod:: dvg_qdeviceio.QDeviceIO.create_worker_jobs
.. automethod:: dvg_qdeviceio.QDeviceIO.start
.. automethod:: dvg_qdeviceio.QDeviceIO.start_worker_DAQ
.. automethod:: dvg_qdeviceio.QDeviceIO.start_worker_jobs
.. automethod:: dvg_qdeviceio.QDeviceIO.quit
.. automethod:: dvg_qdeviceio.QDeviceIO.quit_worker_DAQ
.. automethod:: dvg_qdeviceio.QDeviceIO.quit_worker_jobs
.. automethod:: dvg_qdeviceio.QDeviceIO.pause_DAQ
.. automethod:: dvg_qdeviceio.QDeviceIO.unpause_DAQ
.. automethod:: dvg_qdeviceio.QDeviceIO.wake_up_DAQ
.. automethod:: dvg_qdeviceio.QDeviceIO.send
.. automethod:: dvg_qdeviceio.QDeviceIO.add_to_jobs_queue
.. automethod:: dvg_qdeviceio.QDeviceIO.process_jobs_queue
